@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -47,8 +50,6 @@ kmem_mb_alloc(vm_map_t  mbmap, int size)
 }
 
 pcb_synch() {}
-unix_master() {}
-unix_release() {}
 
 struct proc *
 current_proc(void)
@@ -123,7 +124,8 @@ bdevsw_add(int index, struct bdevsw * bsw)
 
 	if (index == -1) {
 	    devsw = bdevsw;
-	    for(index=0; index < nblkdev; index++, devsw++) {
+	    /* yes, start at 1 to avoid collision with volfs (Radar 2842228) */
+	    for(index=1; index < nblkdev; index++, devsw++) {
 		if(memcmp((char *)devsw, 
 			    (char *)&nobdev, 
 			    sizeof(struct bdevsw)) == 0)
@@ -238,7 +240,28 @@ cdevsw_remove(int index, struct cdevsw * csw)
 	return(index);
 }
 
-int
+static int
+cdev_set_bdev(int cdev, int bdev)
+{
+	extern int chrtoblk_add(int cdev, int bdev);
+
+	return (chrtoblk_set(cdev, bdev));
+}
+
+int  
+cdevsw_add_with_bdev(int index, struct cdevsw * csw, int bdev)
+{
+	index = cdevsw_add(index, csw);
+	if (index < 0) {
+		return (index);
+	}
+	if (cdev_set_bdev(index, bdev) < 0) {
+		cdevsw_remove(index, csw);
+		return (-1);
+	}
+	return (index);
+}
+
 issingleuser(void)
 {
 	char namep[16];
