@@ -112,13 +112,13 @@ static int output_kernel_symbols(struct proc *p)
 				(void **)&orig_mh, &orig_mhsize);
     if (rc_mh && orig_mh)
 	IODTFreeLoaderInfo("Kernel-__HEADER",
-			    (void *)orig_mh, round_page_32(orig_mhsize));
+			    (void *)orig_mh, round_page(orig_mhsize));
 
     rc_sc = IODTGetLoaderInfo("Kernel-__SYMTAB",
 				(void **) &orig_st, &orig_st_size);
     if (rc_sc && orig_st)
 	IODTFreeLoaderInfo("Kernel-__SYMTAB",
-			    (void *)orig_st, round_page_32(orig_st_size));
+			    (void *)orig_st, round_page(orig_st_size));
 
     if (pcred->p_svuid != pcred->p_ruid || pcred->p_svgid != pcred->p_rgid)
 	goto out;
@@ -207,7 +207,7 @@ static int output_kernel_symbols(struct proc *p)
     mh->flags      = orig_mh->flags;
 
     // Initialise the current file offset and addr
-    offset = round_page_32(header_size);
+    offset = round_page(header_size);
     addr = (caddr_t) const_text->addr;	// Load address of __TEXT,__const
 
     /*
@@ -220,7 +220,7 @@ static int output_kernel_symbols(struct proc *p)
     sg->vmaddr   = (unsigned long) addr;
     sg->vmsize   = const_text->size;
     sg->fileoff  = 0;
-    sg->filesize = const_text->size + round_page_32(header_size);
+    sg->filesize = const_text->size + round_page(header_size);
     sg->maxprot  = 0;
     sg->initprot = 0;
     sg->flags    = 0;
@@ -237,7 +237,7 @@ static int output_kernel_symbols(struct proc *p)
 	    const_text = se;
 	}
     }
-    offset = round_page_32((vm_address_t) offset);
+    offset = round_page((vm_address_t) offset);
 
     // Now copy of the __DATA segment load command, the image need
     // not be stored to disk nobody needs it, yet!
@@ -258,7 +258,7 @@ static int output_kernel_symbols(struct proc *p)
 	se->offset = offset;
 	se->nreloc = 0;
     }
-    offset = round_page_32(offset);
+    offset = round_page(offset);
 
 
     /*
