@@ -62,8 +62,7 @@ load_return_t load_machfile(
 	unsigned long		macho_size,
 	load_result_t		*result,
 	thread_act_t		thr_act,
-	vm_map_t		map,
-	boolean_t		clean_regions);
+	vm_map_t			map);
 
 #define LOAD_SUCCESS		0
 #define LOAD_BADARCH		1	/* CPU type/subtype not found */
