@@ -3,23 +3,27 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
 /*      $NetBSD: if_atm.h,v 1.7 1996/11/09 23:02:27 chuck Exp $       */
+/* $FreeBSD: src/sys/net/if_atm.h,v 1.4 1999/12/29 04:38:34 peter Exp $ */
 
 /*
  *
@@ -57,21 +61,15 @@
  * net/if_atm.h
  */
 
-
-#ifndef NO_ATM_PVCEXT
-/*
- * ATM_PVCEXT enables PVC extention: VP/VC shaping
- * and PVC shadow interfaces.
- */
-#define ATM_PVCEXT	/* enable pvc extention */
-#endif
-
 #if defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__)
 #define RTALLOC1(A,B)		rtalloc1((A),(B))
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__APPLE__)
 #define RTALLOC1(A,B)		rtalloc1((A),(B),0UL)
 #endif
 
+#warning if_atm.h is not used by the darwin kernel
+
+
 /*
  * pseudo header for packet transmission
  */
@@ -90,9 +88,6 @@ struct atm_pseudohdr {
 #define ATM_PH_AAL5    0x01	/* use AAL5? (0 == aal0) */
 #define ATM_PH_LLCSNAP 0x02	/* use the LLC SNAP encoding (iff aal5) */
 
-#if ATM_PVCEXT
-#define ATM_PH_INERNAL  0x20	/* reserve for kernel internal use */
-#endif
 #define ATM_PH_DRIVER7  0x40	/* reserve for driver's use */
 #define ATM_PH_DRIVER8  0x80	/* reserve for driver's use */
 
@@ -111,28 +106,6 @@ struct atm_pseudoioctl {
 #define SIOCATMENA	_IOWR('a', 123, struct atm_pseudoioctl) /* enable */
 #define SIOCATMDIS	_IOWR('a', 124, struct atm_pseudoioctl) /* disable */
 
-#if ATM_PVCEXT
-
-/* structure to control PVC transmitter */
-struct pvctxreq {
-    /* first entry must be compatible with struct ifreq */
-    char pvc_ifname[IFNAMSIZ];		/* if name, e.g. "en0" */
-    struct atm_pseudohdr pvc_aph;	/* (flags) + vpi:vci */
-    struct atm_pseudohdr pvc_joint;	/* for vp shaping: another vc
-					   to share the shaper */
-    int pvc_pcr;			/* peak cell rate (shaper value) */
-};
-
-/* use ifioctl for now */
-#define SIOCSPVCTX	_IOWR('i', 95, struct pvctxreq)
-#define SIOCGPVCTX	_IOWR('i', 96, struct pvctxreq)
-#define SIOCSPVCSIF	_IOWR('i', 97, struct ifreq)
-#define SIOCGPVCSIF	_IOWR('i', 98, struct ifreq)
-
-#ifdef KERNEL
-#define ATM_PH_PVCSIF	ATM_PH_INERNAL	/* pvc shadow interface */
-#endif
-#endif /* ATM_PVCEXT */
 
 /*
  * XXX forget all the garbage in if_llc.h and do it the easy way
@@ -152,16 +125,12 @@ struct atmllc {
 }
 
 #ifdef KERNEL
+#ifdef __APPLE_API_PRIVATE
 void	atm_ifattach __P((struct ifnet *));
 void	atm_input __P((struct ifnet *, struct atm_pseudohdr *,
 		struct mbuf *, void *));
 int	atm_output __P((struct ifnet *, struct mbuf *, struct sockaddr *, 
 		struct rtentry *));
+#endif /* __APPLE_API_PRIVATE */
 #endif
-#if ATM_PVCEXT
-char *shadow2if __P((char *));
-#ifdef KERNEL
-struct ifnet *pvc_attach __P((struct ifnet *));
-int pvc_setaph __P((struct ifnet *, struct atm_pseudohdr *));
-#endif
-#endif
+
