@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -1104,7 +1107,7 @@ asp_ack_reply(gref, mioc)
 			if ((m = scb->sess_ioc) == 0) {
 				scb->sess_ioc = mdata;
 				if (scb->get_wait)
-					thread_wakeup(&scb->event);
+					wakeup(&scb->event);
 				else
 					atalk_notify_sel(gref);
 			} else {
@@ -1317,7 +1320,7 @@ asp_ack_reply(gref, mioc)
 			gbuf_freem(mioc);
 			ATDISABLE(s, scb->lock);
 			if (scb->get_wait)
-				thread_wakeup(&scb->event);
+				wakeup(&scb->event);
 			else
 				atalk_notify_sel(gref);
 			ATENABLE(s, scb->lock);
@@ -1753,7 +1756,7 @@ asp_hangup(scb)
 	 */
 	if (scb->rem_addr.node) {
 		if (scb->get_wait) {
-			thread_wakeup(&scb->event);
+			wakeup(&scb->event);
 			ATENABLE(s, scb->lock);
 		} else {
 			ATENABLE(s, scb->lock);
@@ -1882,7 +1885,7 @@ asp_putnext(gref, mproto)
 		scb->snd_stop = 1;
 
 	if (scb->get_wait) {
-		thread_wakeup(&scb->event);
+		wakeup(&scb->event);
 		ATENABLE(s, scb->lock);
 	} else if (mproto == scb->sess_ioc) {
 		ATENABLE(s, scb->lock);
