@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -880,6 +883,14 @@ void routing_needed(mp, ifID, bypass)
 
 		/* somehow, come to that point... */
 
+		/* if multihomed - need to set source address to the interface
+		 * the packet is being sent from.
+		 */
+		if (MULTIHOME_MODE) {
+			NET_ASSIGN(ddp->src_net, ifID_table[Entry->NetPort]->ifThisNode.s_net);
+			ddp->src_node = ifID_table[Entry->NetPort]->ifThisNode.s_node;
+		}
+
 		ifID->ifStatistics.fwdPkts++;
 		ifID->ifStatistics.fwdBytes += msgsize;
 
@@ -1108,8 +1119,8 @@ void getIfUsage(zone, ifs_in_zone)
      int zone;
      at_ifnames_t *ifs_in_zone;
 
-/* sets a "1" in each element of the char array for each I/F in the
-   requested zone. The char array has a 1:1 correspondence with the
+/* sets the interface name in each element of the array for each I/F in the
+   requested zone. The array has a 1:1 correspondence with the
    ifID_table. Zone is assumed to be valid and local, so if we're in
    single port mode, we'll set the home port and thats it.
 */
