@@ -324,8 +324,7 @@ struct proc *proc;
 	       return EBADF;
 	  }
      }
-     *grefp = (gref_t *)fp->f_data;
-     if (*grefp == 0 || *grefp == (gref_t *)(-1)) {
+     if ((*grefp = (gref_t *)fp->f_data) == 0) {
 	  thread_funnel_switch(KERNEL_FUNNEL, NETWORK_FUNNEL);
 	  return EBADF;
      }
