@@ -208,7 +208,7 @@ nfs_boot_init(nd, procp)
 	if (netboot_iaddr(&my_ip) == FALSE) {
 	    printf("nfs_boot: networking is not initialized\n");
 	    error = ENXIO;
-	    goto failed_noswitch;
+	    goto failed;
 	}
 
 	/* get the root path information */
@@ -290,9 +290,8 @@ nfs_boot_init(nd, procp)
 		error = 0;
 	}
 #endif NO_MOUNT_PRIVATE
-failed:
+ failed:
 	thread_funnel_switch(NETWORK_FUNNEL, KERNEL_FUNNEL);
-failed_noswitch:
 	return (error);
 }
 
