@@ -1,21 +1,24 @@
 /*
- * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -58,6 +61,7 @@
 #ifndef	_SYS_MMAN_H_
 #define _SYS_MMAN_H_
 
+#include <sys/appleapiopts.h>
 #include <mach/shared_memory_server.h>
 
 /*
@@ -127,6 +131,11 @@
 #define	MADV_WILLNEED	3	/* will need these pages */
 #define	MADV_DONTNEED	4	/* dont need these pages */
 #define	MADV_FREE	5	/* dont need these pages, and junk contents */
+#define	POSIX_MADV_NORMAL	MADV_NORMAL
+#define	POSIX_MADV_RANDOM	MADV_RANDOM
+#define	POSIX_MADV_SEQUENTIAL	MADV_SEQUENTIAL
+#define	POSIX_MADV_WILLNEED	MADV_WILLNEED
+#define	POSIX_MADV_DONTNEED	MADV_DONTNEED
 
 /*
  * Return bits from mincore
@@ -157,9 +166,14 @@ int	munlock __P((const void *, size_t));
 int	munmap __P((void *, size_t));
 int	shm_open __P((const char *, int, ...));
 int	shm_unlink __P((const char *));
+int	posix_madvise __P((void *, size_t, int));
 #ifndef _POSIX_SOURCE
-int	load_shared_file __P((char *, caddr_t, u_long, caddr_t *, int, sf_mapping_t *, int *));
+#ifdef __APPLE_API_PRIVATE
+int	load_shared_file __P((char *, caddr_t, u_long,
+		caddr_t *, int, sf_mapping_t *, int *));
 int	reset_shared_file __P((caddr_t *, int, sf_mapping_t *));
+int	new_system_shared_regions __P((void));
+#endif /* __APPLE_API_PRIVATE */
 int	madvise __P((void *, size_t, int));
 int	mincore __P((const void *, size_t, char *));
 int	minherit __P((void *, size_t, int));
