@@ -1,21 +1,24 @@
 /*
- * Copyright (c) 1999, 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1999, 2000-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -31,6 +34,7 @@
 #ifndef	_SYS_UBC_H_
 #define	_SYS_UBC_H_
 
+#include <sys/appleapiopts.h>
 #include <sys/types.h>
 #include <sys/ucred.h>
 #include <sys/vnode.h>
@@ -42,6 +46,7 @@
 #define UBC_INFO_NULL	((struct ubc_info *) 0)
 #define UBC_NOINFO		((struct ubc_info *)0xDEADD1ED)
 
+#ifdef __APPLE_API_PRIVATE
 extern struct zone	*ubc_info_zone;
 
 /*
@@ -58,6 +63,7 @@ struct ubc_info {
 	int						ui_refcount;/* ref count on the ubc_info */
 	off_t					ui_size;	/* file size for the vnode */
 	long					ui_mapped;	/* is it currently mapped */
+	void					*ui_owner;	/* for recursive ubc_busy */
 };
 
 /* Defines for ui_flags */
@@ -67,7 +73,12 @@ struct ubc_info {
 #define UI_HASOBJREF	0x00000004		/* hold a reference on object */
 #define UI_WASMAPPED	0x00000008		/* vnode was mapped */
 #define	UI_DONTCACHE	0x00000010		/* do not cache object */
+#define	UI_BUSY			0x00000020		/* for VM synchronization */
+#define	UI_WANTED		0x00000040		/* for VM synchronization */
 
+#endif /* __APPLE_API_PRIVATE */
+
+#ifdef __APPLE_API_EVOLVING
 /*
  * exported primitives for loadable file systems.
  */
@@ -154,5 +165,7 @@ __END_DECLS
 #define UBC_FLAGS_NONE		0x0000
 #define UBC_HOLDOBJECT		0x0001
 
+#endif /* __APPLE_API_EVOLVING */
+
 #endif	/* _SYS_UBC_H_ */
 
