@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -57,6 +60,8 @@
 #ifndef _SYS_UN_H_
 #define _SYS_UN_H_
 
+#include <sys/appleapiopts.h>
+
 /*
  * Definitions for UNIX IPC domain.
  */
@@ -67,6 +72,7 @@ struct	sockaddr_un {
 };
 
 #ifdef KERNEL
+#ifdef __APPLE_API_PRIVATE
 struct mbuf;
 struct socket;
 
@@ -77,6 +83,7 @@ void	unp_dispose __P((struct mbuf *m));
 int	unp_externalize __P((struct mbuf *rights));
 void	unp_init __P((void));
 extern	struct pr_usrreqs uipc_usrreqs;
+#endif /* __APPLE_API_PRIVATE */
 #else /* !KERNEL */
 
 /* actual length of an initialized sockaddr_un */
