@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -32,20 +35,14 @@
 
 #include <sys/types.h>
 #include <sys/param.h>
+#include <sys/quota.h>
 #include <ufs/ufs/ufs_byte_order.h>
 #include <architecture/byte_order.h>
 
-
-
-#if 0
-#define	byte_swap_longlong(thing) ((thing) = NXSwapBigLongLongToHost(thing))
-#define	byte_swap_int(thing) ((thing) = NXSwapBigLongToHost(thing))
-#define	byte_swap_short(thing) ((thing) = NXSwapBigShortToHost(thing))
-#else
 #define	byte_swap_longlong(thing) ((thing) = NXSwapLongLong(thing))
 #define	byte_swap_int(thing) ((thing) = NXSwapLong(thing))
 #define	byte_swap_short(thing) ((thing) = NXSwapShort(thing))
-#endif
+
 void
 byte_swap_longlongs(unsigned long long *array, int count)
 {
@@ -64,7 +61,6 @@ byte_swap_ints(int *array, int count)
 		byte_swap_int(array[i]);
 }
 
-
 void
 byte_swap_shorts(short *array, int count)
 {
@@ -74,7 +70,6 @@ byte_swap_shorts(short *array, int count)
 		byte_swap_short(array[i]);
 }
 
-
 void
 byte_swap_sbin(struct fs *sb)
 {
@@ -119,6 +114,7 @@ byte_swap_sbout(struct fs *sb)
 	byte_swap_longlongs((u_int64_t *)&sb->fs_maxfilesize,3);
 	byte_swap_ints((int32_t *)&sb->fs_state, 6);
 }
+
 void
 byte_swap_csum(struct csum *cs)
 {
@@ -173,7 +169,7 @@ byte_swap_cgin(struct cg *cg, struct fs * fs)
 
 }
 
-// This is for the new 4.4 cylinder group block
+/* This is for the new 4.4 cylinder group block */
 void
 byte_swap_cgout(struct cg *cg, struct fs * fs)
 {
@@ -220,7 +216,7 @@ byte_swap_cgout(struct cg *cg, struct fs * fs)
 
 }
 
-/* This value should correspond to the value set in the ffs_mounts */
+/* This value MUST correspond to the value set in the ffs_mounts */
 
 #define RESYMLNKLEN 60
 
@@ -231,12 +227,8 @@ byte_swap_inode_in(struct dinode *di, struct inode *ip)
 
 	ip->i_mode = NXSwapShort(di->di_mode);
 	ip->i_nlink = NXSwapShort(di->di_nlink);
-#ifdef LFS
-	ip->i_inumber = NXSwapLong(di->di_u.inumber);
-#else
 	ip->i_oldids[0] = NXSwapShort(di->di_u.oldids[0]);
 	ip->i_oldids[1] = NXSwapShort(di->di_u.oldids[1]);
-#endif
 	ip->i_size = NXSwapLongLong(di->di_size);
 	ip->i_atime = NXSwapLong(di->di_atime);
 	ip->i_atimensec = NXSwapLong(di->di_atimensec);
@@ -259,10 +251,8 @@ byte_swap_inode_in(struct dinode *di, struct inode *ip)
 	ip->i_gid = NXSwapLong(di->di_gid);
 	ip->i_spare[0] = NXSwapLong(di->di_spare[0]);
 	ip->i_spare[1] = NXSwapLong(di->di_spare[1]);
-
 }
 
-
 void
 byte_swap_inode_out(struct inode *ip, struct dinode *di)
 {
@@ -274,12 +264,8 @@ byte_swap_inode_out(struct inode *ip, struct dinode *di)
  
 	di->di_mode = NXSwapShort(ip->i_mode);
 	di->di_nlink = NXSwapShort(ip->i_nlink);
-#ifdef LFS
-	di->di_u.inumber = NXSwapLong(ip->i_inumber);
-#else
 	di->di_u.oldids[0] = NXSwapShort(ip->i_oldids[0]);
 	di->di_u.oldids[1] = NXSwapShort(ip->i_oldids[1]);
-#endif /* LFS */
 	di->di_size = NXSwapLongLong(ip->i_size);
 	di->di_atime = NXSwapLong(ip->i_atime);
 	di->di_atimensec = NXSwapLong(ip->i_atimensec);
@@ -302,10 +288,8 @@ byte_swap_inode_out(struct inode *ip, struct dinode *di)
 	di->di_gid = NXSwapLong(ip->i_gid);
 	di->di_spare[0] = NXSwapLong(ip->i_spare[0]);
 	di->di_spare[1] = NXSwapLong(ip->i_spare[1]);
-
 }
 
-
 void
 byte_swap_direct(struct direct *dirp)
 {
@@ -328,6 +312,7 @@ byte_swap_dir_block_in(char *addr, int count)
 			break;
 	}
 }
+
 void
 byte_swap_dir_out(char *addr, int count)
 {
@@ -371,6 +356,7 @@ byte_swap_dirtemplate_in(struct dirtemplate *dirt)
 	byte_swap_int(dirt->dotdot_ino);
 	byte_swap_short(dirt->dotdot_reclen);
 }
+
 void
 byte_swap_minidir_in(struct direct *dirp)
 {
@@ -379,7 +365,7 @@ byte_swap_minidir_in(struct direct *dirp)
 }
 
 #if 0
-// This is for the compatability (old) cylinder group block
+/* This is for the compatability (old) cylinder group block */
 void
 byte_swap_ocylgroup(struct cg *cg)
 {
@@ -397,5 +383,4 @@ byte_swap_ocylgroup(struct cg *cg)
 	byte_swap_shorts((short *)&cg->cg_b, 32 * 8);
 	byte_swap_int(cg->cg_magic);
 }
-
 #endif /* 0 */
