@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -598,16 +601,16 @@ ffs_pageout(ap)
 
         if (vp->v_mount->mnt_flag & MNT_RDONLY) {
 		if (!nocommit)
-  			kernel_upl_abort_range(pl, pl_offset, size, 
-					       UPL_ABORT_FREE_ON_EMPTY);
+  			ubc_upl_abort_range(pl, pl_offset, size, 
+				UPL_ABORT_FREE_ON_EMPTY);
 		return (EROFS);
 	}
 	fs = ip->I_FS;
 
 	if (f_offset < 0 || f_offset >= ip->i_size) {
 	        if (!nocommit)
-		        kernel_upl_abort_range(pl, pl_offset, size, 
-					       UPL_ABORT_FREE_ON_EMPTY);
+		        ubc_upl_abort_range(pl, pl_offset, size, 
+				UPL_ABORT_FREE_ON_EMPTY);
 		return (EINVAL);
 	}
 
@@ -671,8 +674,8 @@ ffs_pageout(ap)
 		lupl_offset = size - save_size;
 		resid = round_page(save_size);
 		if (!nocommit)
-			kernel_upl_abort_range(pl, lupl_offset,
-					       resid, UPL_ABORT_FREE_ON_EMPTY);
+			ubc_upl_abort_range(pl, lupl_offset, resid,
+				UPL_ABORT_FREE_ON_EMPTY);
 		if(!error)
 			error= save_error;
 	}
