@@ -1,21 +1,24 @@
 /*
- * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -72,8 +75,6 @@ int (*mountroot)() = NULL;
  */
 extern	struct vfsops ufs_vfsops;
 extern	int ffs_mountroot();
-extern	struct vfsops lfs_vfsops;
-extern	int lfs_mountroot();
 extern	struct vfsops mfs_vfsops;
 extern	int mfs_mountroot();
 extern  struct vfsops hfs_vfsops;
@@ -84,13 +85,9 @@ extern	int cd9660_mountroot();
 extern	struct vfsops nfs_vfsops;
 extern	int nfs_mountroot();
 extern	struct vfsops afs_vfsops;
-extern	struct vfsops procfs_vfsops;
 extern	struct vfsops null_vfsops;
 extern	struct vfsops union_vfsops;
-extern	struct vfsops umap_vfsops;
-extern	struct vfsops portal_vfsops;
 extern	struct vfsops fdesc_vfsops;
-extern	struct vfsops kernfs_vfsops;
 extern	struct vfsops devfs_vfsops;
 
 /*
@@ -112,11 +109,6 @@ static struct vfsconf vfsconflist[] = {
 	{ &cd9660_vfsops, "cd9660", 14, 0, MNT_LOCAL | MNT_DOVOLFS, cd9660_mountroot, NULL },
 #endif
 
-	/* Log-based Filesystem */
-#if LFS
-	{ &lfs_vfsops, "lfs", 5, 0, MNT_LOCAL, lfs_mountroot, NULL },
-#endif
-
 	/* Memory-based Filesystem */
 #if MFS
 	{ &mfs_vfsops, "mfs", 3, 0, MNT_LOCAL, mfs_mountroot, NULL },
@@ -132,11 +124,6 @@ static struct vfsconf vfsconflist[] = {
 	{ &afs_vfsops, "andrewfs", 13, 0, 0, afs_mountroot, NULL },
 #endif
 
-	/* /proc Filesystem */
-#if PROCFS
-	{ &procfs_vfsops, "procfs", 12, 0, 0, NULL, NULL },
-#endif
-
 	/* Loopback (Minimal) Filesystem Layer */
 #if NULLFS
 	{ &null_vfsops, "loopback", 9, 0, 0, NULL, NULL },
@@ -147,34 +134,25 @@ static struct vfsconf vfsconflist[] = {
 	{ &union_vfsops, "union", 15, 0, 0, NULL, NULL },
 #endif
 
-	/* User/Group Identifer Remapping Filesystem */
-#if UMAPFS
-	{ &umap_vfsops, "umap", 10, 0, 0, NULL, NULL },
-#endif
-
-	/* Portal Filesystem */
-#if PORTAL
-	{ &portal_vfsops, "portal", 8, 0, 0, NULL, NULL },
-#endif
-
 	/* File Descriptor Filesystem */
 #if FDESC
 	{ &fdesc_vfsops, "fdesc", 7, 0, 0, NULL, NULL },
 #endif
 
-	/* Kernel Information Filesystem */
-#if KERNFS
-	{ &kernfs_vfsops, "kernfs", 11, 0, 0, NULL, NULL },
-#endif
-
 	/* Volume ID Filesystem */
 #if VOLFS
 	{ &volfs_vfsops, "volfs", 18, 0, 0, NULL, NULL },
 #endif
+
 	/* Device Filesystem */
 #if DEVFS
 	{ &devfs_vfsops, "devfs", 19, 0, 0, NULL, NULL },
 #endif
+
+	{0},
+	{0},
+	{0},
+	{0},
 	{0},
 	{0},
 	{0},
@@ -206,9 +184,6 @@ struct vfsconf *vfsconf = vfsconflist;
 extern struct vnodeopv_desc ffs_vnodeop_opv_desc;
 extern struct vnodeopv_desc ffs_specop_opv_desc;
 extern struct vnodeopv_desc ffs_fifoop_opv_desc;
-extern struct vnodeopv_desc lfs_vnodeop_opv_desc;
-extern struct vnodeopv_desc lfs_specop_opv_desc;
-extern struct vnodeopv_desc lfs_fifoop_opv_desc;
 extern struct vnodeopv_desc mfs_vnodeop_opv_desc;
 extern struct vnodeopv_desc dead_vnodeop_opv_desc;
 extern struct vnodeopv_desc fifo_vnodeop_opv_desc;
@@ -217,11 +192,7 @@ extern struct vnodeopv_desc nfsv2_vnodeop_opv_desc;
 extern struct vnodeopv_desc spec_nfsv2nodeop_opv_desc;
 extern struct vnodeopv_desc fifo_nfsv2nodeop_opv_desc;
 extern struct vnodeopv_desc fdesc_vnodeop_opv_desc;
-extern struct vnodeopv_desc portal_vnodeop_opv_desc;
 extern struct vnodeopv_desc null_vnodeop_opv_desc;
-extern struct vnodeopv_desc umap_vnodeop_opv_desc;
-extern struct vnodeopv_desc kernfs_vnodeop_opv_desc;
-extern struct vnodeopv_desc procfs_vnodeop_opv_desc;
 extern struct vnodeopv_desc hfs_vnodeop_opv_desc;
 extern struct vnodeopv_desc hfs_specop_opv_desc;
 extern struct vnodeopv_desc hfs_fifoop_opv_desc;
@@ -230,7 +201,6 @@ extern struct vnodeopv_desc cd9660_vnodeop_opv_desc;
 extern struct vnodeopv_desc cd9660_specop_opv_desc;
 extern struct vnodeopv_desc cd9660_fifoop_opv_desc;
 extern struct vnodeopv_desc union_vnodeop_opv_desc;
-extern struct vnodeopv_desc procfs_vnodeop_opv_desc;
 extern struct vnodeopv_desc devfs_vnodeop_opv_desc;
 extern struct vnodeopv_desc devfs_spec_vnodeop_opv_desc;
 
@@ -245,13 +215,6 @@ struct vnodeopv_desc *vfs_opv_descs[] = {
 	&fifo_vnodeop_opv_desc,
 #endif
 	&spec_vnodeop_opv_desc,
-#if LFS
-	&lfs_vnodeop_opv_desc,
-	&lfs_specop_opv_desc,
-#if FIFO
-	&lfs_fifoop_opv_desc,
-#endif
-#endif
 #if MFS
 	&mfs_vnodeop_opv_desc,
 #endif
@@ -265,21 +228,9 @@ struct vnodeopv_desc *vfs_opv_descs[] = {
 #if FDESC
 	&fdesc_vnodeop_opv_desc,
 #endif
-#if PORTAL
-	&portal_vnodeop_opv_desc,
-#endif
 #if NULLFS
 	&null_vnodeop_opv_desc,
 #endif
-#if UMAPFS
-	&umap_vnodeop_opv_desc,
-#endif
-#if KERNFS
-	&kernfs_vnodeop_opv_desc,
-#endif
-#if PROCFS
-	&procfs_vnodeop_opv_desc,
-#endif
 #if HFS
 	&hfs_vnodeop_opv_desc,
 	&hfs_specop_opv_desc,
