@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -45,11 +48,15 @@ extern int PEGetPlatformEpoch( void );
 
 enum {
   kPEHaltCPU,
-  kPERestartCPU
+  kPERestartCPU,
+  kPEHangCPU
 };
 extern int (*PE_halt_restart)(unsigned int type);
 extern int PEHaltRestart(unsigned int type);
 
+// Save the Panic Info.  Returns the number of bytes saved.
+extern unsigned long PESavePanicInfo(unsigned char *buffer, unsigned long  length);
+
 extern long PEGetGMTTimeOfDay( void );
 extern void PESetGMTTimeOfDay( long secs );
   
@@ -143,7 +150,10 @@ public:
     virtual bool hasPrivPMFeature (unsigned long privFeatureMask);
     virtual int  numBatteriesSupported (void);
 
-    OSMetaClassDeclareReservedUnused(IOPlatformExpert,  0);
+    virtual IOByteCount savePanicInfo(UInt8 *buffer, IOByteCount length);
+
+    OSMetaClassDeclareReservedUsed(IOPlatformExpert,  0);
+
     OSMetaClassDeclareReservedUnused(IOPlatformExpert,  1);
     OSMetaClassDeclareReservedUnused(IOPlatformExpert,  2);
     OSMetaClassDeclareReservedUnused(IOPlatformExpert,  3);
@@ -221,6 +231,8 @@ public:
 					       IOByteCount offset, UInt8 * buffer,
 					       IOByteCount length);
 
+    virtual IOByteCount savePanicInfo(UInt8 *buffer, IOByteCount length);
+
     OSMetaClassDeclareReservedUnused(IODTPlatformExpert,  0);
     OSMetaClassDeclareReservedUnused(IODTPlatformExpert,  1);
     OSMetaClassDeclareReservedUnused(IODTPlatformExpert,  2);
