@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -49,14 +52,35 @@
 #define _IOKIT_IOSHAREDLOCKIMP_H
 
 #include <architecture/ppc/asm_help.h>
+#ifdef KERNEL
+#undef END
+#include <mach/ppc/asm.h>
+#endif
 
-// 'Till we're building in kernel
 .macro DISABLE_PREEMPTION
 #ifdef KERNEL
+	stwu	r1,-(FM_SIZE)(r1)
+	mflr	r0
+	stw		r3,FM_ARG0(r1)
+	stw		r0,(FM_SIZE+FM_LR_SAVE)(r1)
+	bl		EXT(_disable_preemption)
+	lwz		r3,FM_ARG0(r1)
+	lwz		r1,0(r1)
+	lwz		r0,FM_LR_SAVE(r1)
+	mtlr	r0
 #endif
 .endmacro
 .macro ENABLE_PREEMPTION
 #ifdef KERNEL
+	stwu	r1,-(FM_SIZE)(r1)
+	mflr	r0
+	stw		r3,FM_ARG0(r1)
+	stw		r0,(FM_SIZE+FM_LR_SAVE)(r1)
+	bl		EXT(_enable_preemption)
+	lwz		r3,FM_ARG0(r1)
+	lwz		r1,0(r1)
+	lwz		r0,FM_LR_SAVE(r1)
+	mtlr	r0
 #endif
 .endmacro
 
