@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -63,11 +66,16 @@ private:
 protected:
 
 /*! @function release
-    @abstract Primary implementation of the release mechanism.
-    @discussion  If $link retainCount <= the when argument then call $link free().  This indirect implementation of $link release allows the developer to break reference circularity.  An example of this sort of problem is a parent/child mutual reference, either the parent or child can implement: void release() { release(2); } thus breaking the cirularity. 
-    @param when When retainCount == when then call free(). */
+    @abstract untagged release(when) mechansim.
+    @param when Pass through to taggedRelease. */
     virtual void release(int when) const;
 
+/*! @function taggedRelease
+    @abstract Primary implementation of the tagged release mechanism.
+    @discussion  If $link retainCount <= the when argument then call $link free().  This indirect implementation of $link release allows the developer to break reference circularity.  An example of this sort of problem is a parent/child mutual reference, either the parent or child can implement: void taggedRelease(tag) { taggedRelease(tag, 2); } thus breaking the cirularity. 
+    @param when If retainCount == when then call free(). */
+    virtual void taggedRelease(const void *tag, const int when) const;
+
 /*! @function init
     @abstract Mac OS X kernel's primary mechanism for constructing objects.
     @discussion Your responsibility as a subclass author is to override the init method of your parent.  In general most of our implementations call <super>::init() before doing local initialisation, if the parent fails then return false immediately.  If you have a failure during you local initialisation then return false.
@@ -110,14 +118,28 @@ public:
 
 /*! @function retain
     @abstract Retain a reference in this object.
+    @discussion Takes a reference that is NULL tagged.  See taggedRetain().
 */
     virtual void retain() const;
 
 /*! @function release
     @abstract Release a reference to this object
+    @discussion Removes a reference that is NULL tagged.  See taggedRelease().
 */
     virtual void release() const;
 
+/*! @function taggedRetain
+    @abstract Retain a tagged reference in this object.
+    @param tag Retain a reference on this object with this tag, see taggedRelease.
+*/
+    virtual void taggedRetain(const void *tag = 0) const;
+
+/*! @function taggedRelease
+    @abstract Release a tagged reference to this object
+    @param tag Remove a reference on this object with this tag, if an attempt is made to remove a reference that isn't associated with this tag the kernel will panic immediately.
+*/
+    virtual void taggedRelease(const void *tag = 0) const;
+
 /*! @function serialize
     @abstract 
     @discussion 
