@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -105,6 +108,9 @@ typedef unsigned int	pt_entry_t;
 #define PTESHIFT	12	/* page table shift */
 #define PTEMASK		0x3ff	/* mask for page table index */
 
+
+#define	VM_WIMG_DEFAULT		VM_MEM_COHERENT
+
 /*
  *	Convert kernel virtual address to linear address
  */
@@ -150,6 +156,13 @@ typedef unsigned int	pt_entry_t;
 #define	pte_to_pa(p)		((p) & INTEL_PTE_PFN)
 #define	pte_increment_pa(p)	((p) += INTEL_OFFMASK+1)
 
+#define PMAP_DEFAULT_CACHE	0
+#define PMAP_INHIBIT_CACHE	1
+#define PMAP_GUARDED_CACHE	2
+#define PMAP_ACTIVATE_CACHE	4
+#define PMAP_NO_GUARD_CACHE	8
+
+
 /*
  *	Convert page table entry to kernel virtual address
  */
@@ -512,6 +525,8 @@ extern void flush_dcache(vm_offset_t addr, unsigned count, int phys);
 #define	pmap_copy(dst_pmap,src_pmap,dst_addr,len,src_addr)
 #define	pmap_attribute(pmap,addr,size,attr,value) \
 					(KERN_INVALID_ADDRESS)
+#define	pmap_attribute_cache_sync(addr,size,attr,value) \
+					(KERN_INVALID_ADDRESS)
 #define pmap_sync_caches_phys(pa) \
 					(KERN_INVALID_ADDRESS)
 
