@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -173,7 +176,7 @@ user_page_fault_continue(
 	register thread_t	cur_thr = current_thread();
 	register struct i386_saved_state *regs = USER_REGS(thr_act);
 
-	if ((kr == KERN_SUCCESS) && (kr == KERN_ABORTED)) {
+	if ((kr == KERN_SUCCESS) || (kr == KERN_ABORTED)) {
 #if	MACH_KDB
 		if (!db_breakpoints_inserted) {
 			db_set_breakpoints();
@@ -355,7 +358,7 @@ kernel_trap(
 					  trunc_page((vm_offset_t)subcode),
 					  VM_PROT_READ|VM_PROT_WRITE,
 					  FALSE, 
-					  (map == kernel_map) ? interruptible : THREAD_ABORTSAFE);
+					  (map == kernel_map) ? interruptible : THREAD_ABORTSAFE, NULL, 0);
 		}
 #if	MACH_KDB
 		if (result == KERN_SUCCESS) {
@@ -577,7 +580,7 @@ user_trap(
 				trunc_page((vm_offset_t)subcode),
 				prot,
 				FALSE,
-				THREAD_ABORTSAFE));
+				THREAD_ABORTSAFE, NULL, 0));
 			/* NOTREACHED */
 		}
 		else {
@@ -589,7 +592,7 @@ user_trap(
 				trunc_page((vm_offset_t)subcode),
 				prot,
 				FALSE,
-				(map == kernel_map) ? THREAD_UNINT : THREAD_ABORTSAFE);
+				(map == kernel_map) ? THREAD_UNINT : THREAD_ABORTSAFE, NULL, 0);
 			if ((result != KERN_SUCCESS) && (result != KERN_ABORTED)) {
 				/*
 				 * Must expand vm_fault by hand,
@@ -1123,7 +1126,7 @@ i386_astintr(int preemption)
 	mp_enable_preemption();
 #endif
 
-	    ast_taken(preemption, mask, s
+	    ast_taken(mask, s
 #if	FAST_IDLE
 		      ,NO_IDLE_THREAD
 #endif	/* FAST_IDLE */
