@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -83,23 +86,13 @@ thread_quantum_expire(
 {
 	register processor_t		myprocessor = p0;
 	register thread_t			thread = p1;
-	register processor_set_t	pset;
 	spl_t						s;
 
-	pset = myprocessor->processor_set;
-
-	/*
-	 *	Update set_quanta for timesharing.
-	 */
-	pset->set_quanta = pset->machine_quanta[
-							(pset->runq.count > pset->processor_count) ?
-								  pset->processor_count : pset->runq.count];
-
 	s = splsched();
 	thread_lock(thread);
 
 	/*
-	 * Check for failsafe trip.
+	 *	Check for fail-safe trip.
 	 */
 	if (!(thread->sched_mode & TH_MODE_TIMESHARE)) {
 		extern uint64_t		max_unsafe_computation;
@@ -107,15 +100,12 @@ thread_quantum_expire(
 
 		new_computation = myprocessor->quantum_end;
 		new_computation -= thread->computation_epoch;
-		if (new_computation + thread->metered_computation >
+		if (new_computation + thread->computation_metered >
 											max_unsafe_computation) {
 			extern uint32_t		sched_safe_duration;
 
 			if (thread->sched_mode & TH_MODE_REALTIME) {
-				if (thread->depress_priority < 0)
-					thread->priority = MINPRI;
-				else
-					thread->depress_priority = MINPRI;
+				thread->priority = DEPRESSPRI;
 
 				thread->safe_mode |= TH_MODE_REALTIME;
 				thread->sched_mode &= ~TH_MODE_REALTIME;
@@ -123,21 +113,29 @@ thread_quantum_expire(
 
 			thread->safe_release = sched_tick + sched_safe_duration;
 			thread->sched_mode |= (TH_MODE_FAILSAFE|TH_MODE_TIMESHARE);
+			thread->sched_mode &= ~TH_MODE_PREEMPT;
 		}
 	}
 		
 	/*
-	 *	Now recompute the priority of the thread if appropriate.
+	 *	Recompute scheduled priority if appropriate.
 	 */
 	if (thread->sched_stamp != sched_tick)
 		update_priority(thread);
 	else
-	if (	(thread->sched_mode & TH_MODE_TIMESHARE)	&&
-				thread->depress_priority < 0				) {
+	if (thread->sched_mode & TH_MODE_TIMESHARE) {
 		thread_timer_delta(thread);
 		thread->sched_usage += thread->sched_delta;
 		thread->sched_delta = 0;
-		compute_my_priority(thread);
+
+		/*
+		 * Adjust the scheduled priority if
+		 * the thread has not been promoted
+		 * and is not depressed.
+		 */
+		if (	!(thread->sched_mode & TH_MODE_PROMOTED)	&&
+				!(thread->sched_mode & TH_MODE_ISDEPRESSED)		)
+			compute_my_priority(thread);
 	}
 
 	/*
@@ -153,10 +151,11 @@ thread_quantum_expire(
 							thread, myprocessor->quantum_end);
 
 	thread_unlock(thread);
-	splx(s);
 
 	/*
 	 * Check for and schedule ast if needed.
 	 */
-	ast_check();
+	ast_check(myprocessor);
+
+	splx(s);
 }
