@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -69,9 +72,12 @@
 #include <kern/lock.h>
 #include <kern/time_out.h>	/*** ??? temp - remove me soon ***/
 #include <kern/cpu_data.h>
-#include <kern/wait_queue.h>
 
-#ifdef MACH_KERNEL_PRIVATE
+#include <sys/appleapiopts.h>
+
+#ifdef	__APPLE_API_PRIVATE
+
+#ifdef	MACH_KERNEL_PRIVATE
 
 #include <mach_ldebug.h>
 /*
@@ -95,13 +101,13 @@ extern void		thread_timer_terminate(void);
 		(thread)->bound_processor = (processor)
 
 /*
- * Prevent a thread from restarting after it blocks interruptibly
+ * Stop a thread and wait for it to stop running.
  */
 extern boolean_t	thread_stop( 
 						thread_t	thread);
 
 /*
- * wait for a thread to stop
+ * Wait for a thread to stop running.
  */
 extern boolean_t	thread_wait(
 						thread_t	thread);
@@ -110,74 +116,66 @@ extern boolean_t	thread_wait(
 extern thread_t	thread_select(
 						processor_t	myprocessor);
 
-extern void		thread_go_locked(
-					 	thread_t	thread,
-						int		result);
+extern kern_return_t thread_go_locked(
+					 	thread_t		thread,
+						wait_result_t	result);
 
 /* Stop old thread and run new thread */
 extern boolean_t thread_invoke(
-						thread_t	old_thread,
-						thread_t	new_thread,
-						int			reason,
-						void        (*continuation)(void));
+						thread_t		old_thread,
+						thread_t		new_thread,
+						int				reason,
+						thread_continue_t continuation);
 
 /* Called when current thread is given new stack */
 extern void		thread_continue(
-						thread_t	old_thread);
+						thread_t		old_thread);
 
 /* Switch directly to a particular thread */
 extern int		thread_run(
-						thread_t	old_thread,
-						void		(*continuation)(void),
-						thread_t	new_thread);
+						thread_t		old_thread,
+						thread_continue_t continuation,
+						thread_t		new_thread);
 
 /* Dispatch a thread not on a run queue */
 extern void		thread_dispatch(
-						thread_t	thread);
+						thread_t		thread);
 
 /* Invoke continuation */
 extern void		call_continuation(
-						void		(*continuation)(void));
+						thread_continue_t continuation);		  
 
-/* Compute effective priority of the specified thread */
+/* Set the current scheduled priority */
+extern void		set_sched_pri(
+					thread_t		thread,
+					int				priority);
+
+/* Set base priority of the specified thread */
+extern void		set_priority(
+					thread_t		thread,
+					int				priority);
+
+/* Reset scheduled priority of thread */
 extern void		compute_priority(
-						thread_t	thread,
-						int			resched);
+					thread_t		thread,
+					boolean_t		override_depress);
 
-/* Version of compute_priority for current thread or
- * thread being manipuldated by scheduler.
- */
+/* Adjust scheduled priority of thread during execution */
 extern void		compute_my_priority(
-						thread_t	thread);
+					thread_t		thread);
 
 /* Periodic scheduler activity */
-extern void		sched_tick_thread(void);
+extern void		sched_tick_init(void);
 
-/* Update priority of thread that has been sleeping or suspended.
- * Used to "catch up" with the system.
+/*
+ * Update thread to the current scheduler tick.
  */
 extern void		update_priority(
-						thread_t	thread);
+					thread_t		thread);
 
 /* Idle thread loop */
 extern void		idle_thread(void);
 
-/*
- *	thread_sleep_interlock:
- *
- *	Cause the current thread to wait until the specified event
- *	occurs.  The specified HW interlock is unlocked before releasing
- *	the cpu.  (This is a convenient way to sleep without manually
- *	calling assert_wait).
- */
-
-#define thread_sleep_interlock(event, lock, interruptible)	\
-MACRO_BEGIN													\
-	assert_wait(event, interruptible);						\
-	interlock_unlock(lock);									\
-	thread_block((void (*)(void)) 0);						\
-MACRO_END
-
 /*
  *	Machine-dependent code must define these functions.
  */
@@ -194,7 +192,7 @@ extern void     thread_syscall_return(
 
 extern thread_t	switch_context(
 						thread_t	old_thread,
-						void		(*continuation)(void),
+						thread_continue_t continuation,
 						thread_t	new_thread);
 
 /* Attach stack to thread */
@@ -228,36 +226,42 @@ extern void		stack_free(thread_t thread);
 /* Collect excess kernel stacks */
 extern void		stack_collect(void);
 
-extern void		set_pri(
-					thread_t	thread,
-					int			pri,
-					boolean_t	resched);
+/* Block current thread, indicating reason */
+extern wait_result_t	thread_block_reason(
+							thread_continue_t	continuation,
+							ast_t				reason);
 
-/* Block current thread, indicating reason (Block or Quantum expiration) */
-extern int		thread_block_reason(
-						void		(*continuation)(void),
-						int		reason);
-
-/* Make thread runnable */
+/* Dispatch a thread for execution */
 extern void		thread_setrun(
-						thread_t	thread,
-						boolean_t	may_preempt,
-						boolean_t	tail);
-/*
- *	Flags for thread_setrun()
- */
+					thread_t	thread,
+					boolean_t	tail);
 
 #define HEAD_Q		0		/* FALSE */
 #define TAIL_Q		1		/* TRUE */
 
 /* Bind thread to a particular processor */
 extern void		thread_bind(
-						thread_t	thread,
-						processor_t	processor);
+						thread_t		thread,
+						processor_t		processor);
 
-extern void		thread_mark_wait_locked(
-						thread_t	thread,
-						int			interruptible);
+/* Set the maximum interrupt level for the thread */
+__private_extern__ wait_interrupt_t thread_interrupt_level(
+						wait_interrupt_t interruptible);
+
+__private_extern__ wait_result_t thread_mark_wait_locked(
+						thread_t		 thread,
+						wait_interrupt_t interruptible);
+
+/* Sleep, unlocking and then relocking a usimple_lock in the process */
+__private_extern__ wait_result_t thread_sleep_fast_usimple_lock(
+						event_t			event,
+						simple_lock_t	lock,
+						wait_interrupt_t interruptible);
+
+/* Wake up locked thread directly, passing result */
+__private_extern__ kern_return_t clear_wait_internal(
+						thread_t		thread,
+						wait_result_t	result);
 
 #endif /* MACH_KERNEL_PRIVATE */
 
@@ -266,21 +270,17 @@ extern void		thread_mark_wait_locked(
  */
 
 /*
- * Cancel a stop and continue the thread if necessary.
+ * Cancel a stop and unblock the thread if already stopped.
  */
 extern void		thread_unstop(
-						thread_t	thread);
+						thread_t		thread);
 
 /* Wake up thread directly, passing result */
-extern void		clear_wait(
-						thread_t	thread,
-						int		result);
-
-/* Bind thread to a particular processor */
-extern void		thread_bind(
-						thread_t	thread,
-						processor_t	processor);
+extern kern_return_t clear_wait(
+						thread_t		thread,
+						wait_result_t	result);
 
+#endif	/* __APPLE_API_PRIVATE */
 
 /*
  * *********************   PUBLIC APIs ************************************
@@ -288,40 +288,67 @@ extern void		thread_bind(
 
 /* Set timer for current thread */
 extern void		thread_set_timer(
-					natural_t		interval,
-					natural_t		scale_factor);
+					uint32_t		interval,
+					uint32_t		scale_factor);
 
 extern void		thread_set_timer_deadline(
-					AbsoluteTime	deadline);
+					uint64_t		deadline);
 
 extern void		thread_cancel_timer(void);
 
-/*
- * thread_stop a thread then wait for it to stop (both of the above)
- */
-extern boolean_t	thread_stop_wait(
-						thread_t	thread);
-
 /* Declare thread will wait on a particular event */
-extern void		assert_wait(
-						event_t		event,
-						int		interruptflag);
+extern wait_result_t assert_wait(
+						event_t			 event,
+						wait_interrupt_t interruptflag);
 
 /* Assert that the thread intends to wait for a timeout */
-extern void		assert_wait_timeout(
-					        natural_t	msecs,
-						int		interruptflags);
+extern wait_result_t assert_wait_timeout(
+						natural_t		 msecs,
+						wait_interrupt_t interruptflags);
+
+/* Sleep, unlocking and then relocking a usimple_lock in the process */
+extern wait_result_t thread_sleep_usimple_lock(
+						event_t			event,
+						usimple_lock_t	lock,
+						wait_interrupt_t interruptible);	
+
+/* Sleep, unlocking and then relocking a mutex in the process */
+extern wait_result_t thread_sleep_mutex(
+						event_t			event,
+						mutex_t			*mutex,
+						wait_interrupt_t interruptible);	
+										
+/* Sleep with a deadline, unlocking and then relocking a mutex in the process */
+extern wait_result_t thread_sleep_mutex_deadline(
+						event_t			event,
+						mutex_t			*mutex,
+						uint64_t		deadline,
+						wait_interrupt_t interruptible);	
+
+/* Sleep, unlocking and then relocking a write lock in the process */
+extern wait_result_t thread_sleep_lock_write(
+						event_t			event,
+						lock_t			*lock,
+						wait_interrupt_t interruptible);	
+									   
+/* Sleep, hinting that a thread funnel may be involved in the process */
+extern wait_result_t thread_sleep_funnel(
+						event_t			event,
+						wait_interrupt_t interruptible);	
 
 /* Wake up thread (or threads) waiting on a particular event */
-extern void		thread_wakeup_prim(
-						event_t		event,
-						boolean_t	one_thread,
-						int		result);
+extern kern_return_t thread_wakeup_prim(
+						event_t			event,
+						boolean_t		one_thread,
+						wait_result_t	result);
+
+#ifdef	__APPLE_API_UNSTABLE
 
 /* Block current thread (Block reason) */
-extern int		thread_block(
-						void		(*continuation)(void));
+extern wait_result_t thread_block(
+						thread_continue_t continuation);
 
+#endif	/* __APPLE_API_UNSTABLE */
 
 /*
  *	Routines defined as macros
@@ -334,37 +361,13 @@ extern int		thread_block(
 #define thread_wakeup_one(x)				\
 			thread_wakeup_prim((x), TRUE, THREAD_AWAKENED)
 
-/*
- *	thread_sleep_mutex:
- *
- *	Cause the current thread to wait until the specified event
- *	occurs.  The specified mutex is unlocked before releasing
- *	the cpu.  (This is a convenient way to sleep without manually
- *	calling assert_wait).
- */
+#if		!defined(MACH_KERNEL_PRIVATE) && !defined(ABSOLUTETIME_SCALAR_TYPE)
 
-#define thread_sleep_mutex(event, lock, interruptible)	\
-MACRO_BEGIN												\
-	assert_wait(event, interruptible);					\
-	mutex_unlock(lock);									\
-	thread_block((void (*)(void)) 0);					\
-MACRO_END
+#include <libkern/OSBase.h>
 
-/*
- *	thread_sleep_simple_lock:
- *
- *	Cause the current thread to wait until the specified event
- *	occurs.  The specified simple_lock is unlocked before releasing
- *	the cpu.  (This is a convenient way to sleep without manually
- *	calling assert_wait).
- */
-
-#define thread_sleep_simple_lock(event, lock, interruptible)	\
-MACRO_BEGIN														\
-	assert_wait(event, interruptible);							\
-	simple_unlock(lock);										\
-	thread_block((void (*)(void)) 0);							\
-MACRO_END
+#define thread_set_timer_deadline(a)	\
+	thread_set_timer_deadline(__OSAbsoluteTime(a))
 
+#endif
 
 #endif	/* _KERN_SCHED_PRIM_H_ */
