@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -90,6 +93,7 @@
 #include <vm/vm_page.h>
 #include <vm/vm_pageout.h>
 #include <machine/pmap.h>
+#include <machine/commpage.h>
 #include <sys/version.h>
 
 #ifdef __ppc__
@@ -153,7 +157,6 @@ setup_main(void)
 	task_init();
 	act_init();
 	thread_init();
-	subsystem_init();
 
 	/*
 	 *	Initialize the Event Trace Analysis Package.
@@ -163,24 +166,20 @@ setup_main(void)
 	
 	/*
 	 *	Create a kernel thread to start the other kernel
-	 *	threads.  Thread_resume (from kernel_thread) calls
-	 *	thread_setrun, which may look at current thread;
-	 *	we must avoid this, since there is no current thread.
+	 *	threads.
 	 */
 	startup_thread = kernel_thread_with_priority(
 										kernel_task, MAXPRI_KERNEL,
 											start_kernel_threads, TRUE, FALSE);
-							
 	/*
-	 * Pretend it is already running, and resume it.
-	 * Since it looks as if it is running, thread_resume
-	 * will not try to put it on the run queues.
+	 * Pretend it is already running.
 	 *
-	 * We can do all of this without locking, because nothing
+	 * We can do this without locking, because nothing
 	 * else is running yet.
 	 */
 	startup_thread->state = TH_RUN;
-	(void) thread_resume(startup_thread->top_act);
+	hw_atomic_add(&startup_thread->processor_set->run_count, 1);
+
 	/*
 	 * Start the thread.
 	 */
@@ -223,6 +222,11 @@ start_kernel_threads(void)
 		splx(s);
 	}
 
+	/*
+	 * Initialize the thread reaper mechanism.
+	 */
+	thread_reaper_init();
+
 	/*
 	 * Initialize the stack swapin mechanism.
 	 */
@@ -245,11 +249,6 @@ start_kernel_threads(void)
 	mapping_adjust();
 #endif
 
-	/*
-	 * Initialize the thread reaper mechanism.
-	 */
-	thread_reaper();
-
 	/*
 	 *	Create the clock service.
 	 */
@@ -267,13 +266,18 @@ start_kernel_threads(void)
 		PE_init_iokit();
 	}
 #endif
+	
+	(void) spllo();		/* Allow interruptions */
+
+    /*
+     *	Fill in the comm area (mapped into every task address space.)
+     */
+    commpage_populate();
 
 	/*
 	 *	Start the user bootstrap.
 	 */
 	
-	(void) spllo();		/* Allow interruptions */
-	
 #ifdef	MACH_BSD
 	{ 
 		extern void bsd_init(void);
@@ -297,13 +301,17 @@ slave_main(void)
 	processor_t		myprocessor = current_processor();
 	thread_t		thread;
 
+	myprocessor->cpu_data = get_cpu_data();
 	thread = myprocessor->next_thread;
 	myprocessor->next_thread = THREAD_NULL;
 	if (thread == THREAD_NULL) {
 		thread = machine_wake_thread;
 		machine_wake_thread = THREAD_NULL;
-		thread_bind(thread, myprocessor);
 	}
+        thread_machine_set_current(thread);
+	if (thread == machine_wake_thread)
+		thread_bind(thread, myprocessor);
+
 	cpu_launch_first_thread(thread);
 	/*NOTREACHED*/
 	panic("slave_main");
@@ -337,19 +345,16 @@ cpu_launch_first_thread(
 	thread_t		thread)
 {
 	register int	mycpu = cpu_number();
+	processor_t		processor = cpu_to_processor(mycpu);
 
-	/* initialize preemption disabled */
-	cpu_data[mycpu].preemption_level = 1;
+	processor->cpu_data->preemption_level = 0;
 
 	cpu_up(mycpu);
 	start_timer(&kernel_timer[mycpu]);
-	clock_get_uptime(&cpu_to_processor(mycpu)->last_dispatch);
+	clock_get_uptime(&processor->last_dispatch);
 
-	if (thread == THREAD_NULL) {
-	    thread = cpu_to_processor(mycpu)->idle_thread;
-		if (thread == THREAD_NULL)
-		    panic("cpu_launch_first_thread");
-	}
+	if (thread == THREAD_NULL || thread == processor->idle_thread)
+		panic("cpu_launch_first_thread");
 
 	rtclock_reset();		/* start realtime clock ticking */
 	PMAP_ACTIVATE_KERNEL(mycpu);
@@ -357,7 +362,9 @@ cpu_launch_first_thread(
 	thread_machine_set_current(thread);
 	thread_lock(thread);
 	thread->state &= ~TH_UNINT;
-	_mk_sp_thread_begin(thread);
+	thread->last_processor = processor;
+	processor->current_pri = thread->sched_pri;
+	_mk_sp_thread_begin(thread, processor);
 	thread_unlock(thread);
 	timer_switch(&thread->system_timer);
 
