@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -62,7 +65,12 @@
 #include <mach/machine/vm_types.h>
 #include <kern/kern_types.h>
 
-#ifdef MACH_KERNEL_PRIVATE
+#include <sys/appleapiopts.h>
+
+#ifdef	__APPLE_API_PRIVATE
+
+#ifdef	MACH_KERNEL_PRIVATE
+
 #include <zone_debug.h>
 #include <mach_kdb.h>
 #include <kern/lock.h>
@@ -101,7 +109,6 @@ struct zone {
 	decl_simple_lock_data(,lock)		/* generic lock */
 };
 
-
 extern void		zone_gc(void);
 extern void		consider_zone_gc(void);
 
@@ -114,8 +121,9 @@ extern void		zone_bootstrap(void);
 /* Init zone module */
 extern void		zone_init(vm_size_t);
 
-#endif /* ! MACH_KERNEL_PRIVATE */
+#endif	/* MACH_KERNEL_PRIVATE */
 
+#endif	/* __APPLE_API_PRIVATE */
 
 /* Allocate from zone */
 extern vm_offset_t	zalloc(
@@ -179,22 +187,34 @@ extern integer_t              zone_free_count(zone_t zone);
 #define Z_EXPAND	3	/* Make zone expandable		*/
 #define	Z_FOREIGN	4	/* Allow collectable zone to contain foreign */
 				/* (not allocated via zalloc) elements. */
-#ifdef MACH_KERNEL_PRIVATE
+
+#ifdef	__APPLE_API_PRIVATE
+
+#ifdef	MACH_KERNEL_PRIVATE
+
 #if	ZONE_DEBUG
+
 #if	MACH_KDB
+
 extern vm_offset_t	next_element(
 				zone_t		z,
 				vm_offset_t	elt);
 
 extern vm_offset_t	first_element(
 				zone_t		z);
+
 #endif	/* MACH_KDB */
+
 extern void		zone_debug_enable(
 				zone_t		z);
 
 extern void		zone_debug_disable(
 				zone_t		z);
+
 #endif	/* ZONE_DEBUG */
-#endif MACH_KERNEL_PRIVATE
+
+#endif	MACH_KERNEL_PRIVATE
+
+#endif	/* __APPLE_API_PRIVATE */
 
 #endif	/* _KERN_ZALLOC_H_ */
