@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -54,10 +57,8 @@
 #ifndef	_MACH_MACHINE_H_
 #define _MACH_MACHINE_H_
 
-#ifdef  MACH_KERNEL_PRIVATE
-#include <cpus.h> 
-#endif  /* MACH_KERNEL_PRIVATE */
- 
+#include <sys/appleapiopts.h>
+
 #include <mach/machine/vm_types.h>
 #include <mach/boolean.h>
 
@@ -91,6 +92,9 @@ typedef integer_t	cpu_subtype_t;
 #define CPU_STATE_IDLE		2
 #define CPU_STATE_NICE		3
 
+#ifdef	KERNEL_PRIVATE
+#ifdef   __APPLE_API_UNSTABLE
+
 struct machine_slot {
 /*boolean_t*/integer_t	is_cpu;		/* is there a cpu in this slot? */
 	cpu_type_t	cpu_type;	/* type of cpu */
@@ -103,10 +107,11 @@ struct machine_slot {
 typedef struct machine_slot	*machine_slot_t;
 typedef struct machine_slot	machine_slot_data_t;	/* bogus */
 
-#ifdef	KERNEL_PRIVATE
 extern struct machine_info	machine_info;
 extern struct machine_slot	machine_slot[];
-#endif
+
+#endif /* __APPLE_API_UNSTABLE */
+#endif /* KERNEL_PRIVATE */
 
 /*
  *	Machine types known by all.
