@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -39,9 +42,9 @@
 #endif /* NCPUS > 1 */
 #include <sys/kdebug.h>
 
-struct ppc_saved_state * interrupt(
+struct savearea * interrupt(
         int type,
-        struct ppc_saved_state *ssp,
+        struct savearea *ssp,
 	unsigned int dsisr,
 	unsigned int dar)
 {
@@ -52,6 +55,14 @@ struct ppc_saved_state * interrupt(
 
 	disable_preemption();
 	
+#if 0
+	{
+		extern void fctx_text(void);
+		fctx_test();
+	}
+#endif
+	
+	
 	current_cpu = cpu_number();
 
 	switch (type) {
@@ -100,7 +111,7 @@ struct ppc_saved_state * interrupt(
 			
 		case T_DECREMENTER:
 			KERNEL_DEBUG_CONSTANT(MACHDBG_CODE(DBG_MACH_EXCP_DECI, 0) | DBG_FUNC_NONE,
-				  isync_mfdec(), ((savearea *)ssp)->save_srr0, 0, 0, 0);
+				  isync_mfdec(), ssp->save_srr0, 0, 0, 0);
 	
 #if 0
 			if (pcsample_enable) {
@@ -128,7 +139,7 @@ struct ppc_saved_state * interrupt(
 			counter_always(c_incoming_interrupts++);
 	
 			KERNEL_DEBUG_CONSTANT(MACHDBG_CODE(DBG_MACH_EXCP_INTR, 0) | DBG_FUNC_START,
-			   current_cpu, ((savearea *)ssp)->save_srr0, 0, 0, 0);
+			   current_cpu, ssp->save_srr0, 0, 0, 0);
 	
 			per_proc_info[current_cpu].interrupt_handler(
 				per_proc_info[current_cpu].interrupt_target, 
