@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -29,6 +32,11 @@
 #include <ppc/proc_reg.h>
 #include <kern/processor.h>
 
+unsigned int max_cpus_initialized = 0;
+
+#define	MAX_CPUS_SET	0x1
+#define	MAX_CPUS_WAIT	0x2
+
 boolean_t get_interrupts_enabled(void);
 
 /* Map memory map IO space */
@@ -121,6 +129,8 @@ void ml_install_interrupt_handler(
 
 	per_proc_info[current_cpu].interrupts_enabled = TRUE;  
 	(void) ml_set_interrupts_enabled(current_state);
+
+	initialize_screen(0, kPEAcquireScreen);
 }
 
 /* Initialize Interrupts */
@@ -192,14 +202,26 @@ void ml_cause_interrupt(void)
 	CreateFakeIO();
 }
 
-void ml_thread_policy( 
+void ml_thread_policy(
 	thread_t thread,
 	unsigned policy_id,
 	unsigned policy_info)
 {
 	if ((policy_id == MACHINE_GROUP) &&
-	    ((per_proc_info[0].pf.Available) & pfSMPcap))
-		thread_bind(thread, master_processor);
+		((per_proc_info[0].pf.Available) & pfSMPcap))
+			thread_bind(thread, master_processor);
+
+	if (policy_info & MACHINE_NETWORK_WORKLOOP) {
+		spl_t		s = splsched();
+
+		thread_lock(thread);
+
+		thread->sched_mode |= TH_MODE_FORCEDPREEMPT;
+		set_priority(thread, thread->priority + 1);
+
+		thread_unlock(thread);
+		splx(s);
+	}
 }
 
 void machine_idle(void)
@@ -287,7 +309,44 @@ ml_enable_nap(int target_cpu, boolean_t nap_enabled)
 }
 
 void
-ml_ppc_get_info(ml_ppc_cpu_info_t *cpu_info)
+ml_init_max_cpus(unsigned long max_cpus)
+{
+	boolean_t current_state;
+
+	current_state = ml_set_interrupts_enabled(FALSE);
+	if (max_cpus_initialized != MAX_CPUS_SET) {
+		if (max_cpus > 0 && max_cpus < NCPUS)
+			machine_info.max_cpus = max_cpus;
+		if (max_cpus_initialized == MAX_CPUS_WAIT)
+			wakeup((event_t)&max_cpus_initialized);
+		max_cpus_initialized = MAX_CPUS_SET;
+	}
+	(void) ml_set_interrupts_enabled(current_state);
+}
+
+int
+ml_get_max_cpus(void)
+{
+	boolean_t current_state;
+
+	current_state = ml_set_interrupts_enabled(FALSE);
+	if (max_cpus_initialized != MAX_CPUS_SET) {
+		max_cpus_initialized = MAX_CPUS_WAIT;
+		assert_wait((event_t)&max_cpus_initialized, THREAD_UNINT);
+		(void)thread_block(THREAD_CONTINUE_NULL);
+	}
+	(void) ml_set_interrupts_enabled(current_state);
+	return(machine_info.max_cpus);
+}
+
+int
+ml_get_current_cpus(void)
+{
+	return machine_info.avail_cpus;
+}
+
+void
+ml_cpu_get_info(ml_cpu_info_t *cpu_info)
 {
   if (cpu_info == 0) return;
   
@@ -361,10 +420,11 @@ init_ast_check(processor_t processor)
 {}
                 
 void
-cause_ast_check(processor_t processor)
+cause_ast_check(
+	processor_t		processor)
 {
-	if ((processor != current_processor())
-	    && (per_proc_info[processor->slot_num].interrupts_enabled == TRUE))
+	if (	processor != current_processor()								&&
+	    	per_proc_info[processor->slot_num].interrupts_enabled == TRUE	)
 		cpu_signal(processor->slot_num, SIGPast, NULL, NULL);
 }
               
@@ -374,9 +434,7 @@ switch_to_shutdown_context(
 	void		(*doshutdown)(processor_t),
 	processor_t	processor)
 {
-	disable_preemption();
 	CreateShutdownCTX();   
-	enable_preemption();
 	return((thread_t)(per_proc_info[cpu_number()].old_thread));
 }
 
