@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -183,8 +186,20 @@ void ml_thread_policy(
 #define MACHINE_NETWORK_WORKLOOP	0x00000001
 #define MACHINE_NETWORK_NETISR		0x00000002
 
-/* Struct for ml_ppc_get_cpu_info */
-struct ml_ppc_cpu_info_t {
+/* Initialize the maximum number of CPUs */
+void ml_init_max_cpus(
+	unsigned long max_cpus);
+
+/* Return the maximum number of CPUs set by ml_init_max_cpus() */
+int ml_get_max_cpus(
+	void);
+
+/* Return the current number of CPUs */
+int ml_get_current_cpus(
+	void);
+
+/* Struct for ml_cpu_get_info */
+struct ml_cpu_info {
 	unsigned long		vector_unit;
 	unsigned long		cache_line_size;
 	unsigned long		l1_icache_size;
@@ -195,10 +210,10 @@ struct ml_ppc_cpu_info_t {
 	unsigned long		l3_cache_size;
 };
 
-typedef struct ml_ppc_cpu_info_t ml_ppc_cpu_info_t;
+typedef struct ml_cpu_info ml_cpu_info_t;
 
 /* Get processor info */
-void ml_ppc_get_info(ml_ppc_cpu_info_t *cpu_info);
+void ml_cpu_get_info(ml_cpu_info_t *cpu_info);
 
 void ml_set_processor_speed(unsigned long speed);
 void ml_set_processor_voltage(unsigned long voltage);
