@@ -52,10 +52,9 @@ extern char *strcpy(char *dest, const char *src);
 extern void vprintf(const char *fmt, va_list args);
 extern void printf(const char *fmt, ...);
 
-extern void	bzero_nc(char* buf, int size); /* uncached-safe */
 extern void bcopy_nc(char *from, char *to, int size); /* uncached-safe */
-extern void bcopy_phys(addr64_t from, addr64_t to, int size); /* Physical to physical copy (ints must be disabled) */
-extern void bcopy_physvir(addr64_t from, addr64_t to, int size); /* Physical to physical copy virtually (ints must be disabled) */
+extern void bcopy_phys(char *from, char *to, int size); /* Physical to physical copy (ints must be disabled) */
+extern void bcopy_physvir(char *from, char *to, int size); /* Physical to physical copy virtually (ints must be disabled) */
 
 extern void ppc_init(boot_args *args);
 extern struct savearea *enterDebugger(unsigned int trap,
@@ -63,10 +62,7 @@ extern struct savearea *enterDebugger(unsigned int trap,
 				      unsigned int dsisr);
 
 extern void draw_panic_dialog(void);
-extern void ppc_vm_init(uint64_t mem_size, boot_args *args);
-
-extern int ppcNull(struct savearea *);
-extern int ppcNullinst(struct savearea *);
+extern void ppc_vm_init(unsigned int mem_size, boot_args *args);
 
 extern void autoconf(void);
 extern void machine_init(void);
@@ -79,14 +75,13 @@ extern void interrupt_init(void);
 extern void interrupt_enable(void);
 extern void interrupt_disable(void);
 extern void disable_bluebox_internal(thread_act_t act);
-extern uint64_t hid0get64(void);
 #if	MACH_KDB
 extern void db_interrupt_enable(void);
 extern void db_interrupt_disable(void);
 #endif	/* MACH_KDB */
 
 extern void phys_zero(vm_offset_t, vm_size_t);
-extern void phys_copy(addr64_t, addr64_t, vm_size_t);
+extern void phys_copy(vm_offset_t, vm_offset_t, vm_size_t);
 
 extern void Load_context(thread_t th);
 
@@ -99,8 +94,6 @@ extern void vec_save(struct facility_context *);
 extern void toss_live_fpu(struct facility_context *);
 extern void toss_live_vec(struct facility_context *);
 
-extern void condStop(unsigned int, unsigned int);
-
 extern int nsec_to_processor_clock_ticks(int nsec);
 
 extern void tick_delay(int ticks);
