@@ -1,21 +1,24 @@
 /*
- * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -61,6 +64,10 @@
 #ifndef	_VM_PMAP_H_
 #define _VM_PMAP_H_
 
+#include <sys/appleapiopts.h>
+
+#ifdef __APPLE_API_PRIVATE
+
 #include <mach/kern_return.h>
 #include <mach/vm_param.h>
 #include <mach/vm_types.h>
@@ -80,7 +87,7 @@
  *	many address spaces.
  */
 
-#ifndef MACH_KERNEL_PRIVATE
+#if !defined(MACH_KERNEL_PRIVATE)
 
 typedef void *pmap_t;
 
@@ -163,12 +170,18 @@ extern void		pmap_enter(	/* Enter a mapping */
 				vm_offset_t	v,
 				vm_offset_t	pa,
 				vm_prot_t	prot,
+				unsigned int	flags,
 				boolean_t	wired);
 
+extern void		pmap_remove_some_phys(
+				pmap_t		pmap,
+				vm_offset_t	pa);
+
 
 /*
  *	Routines that operate on physical addresses.
  */
+
 extern void		pmap_page_protect(	/* Restrict access to page. */
 				vm_offset_t	phys,
 				vm_prot_t	prot);
@@ -254,6 +267,14 @@ extern kern_return_t	(pmap_attribute)(	/* Get/Set special memory
 				vm_machine_attribute_t  attribute,
 				vm_machine_attribute_val_t* value);
 
+extern kern_return_t	(pmap_attribute_cache_sync)(  /* Flush appropriate 
+						       * cache based on
+						       * phys addr sent */
+				vm_offset_t	addr, 
+				vm_size_t	size, 
+				vm_machine_attribute_t attribute, 
+				vm_machine_attribute_val_t* value);
+
 /*
  * Routines defined as macros.
  */
@@ -291,31 +312,19 @@ extern kern_return_t	(pmap_attribute)(	/* Get/Set special memory
 /*
  *	Macro to be used in place of pmap_enter()
  */
-#define PMAP_ENTER(pmap, virtual_address, page, protection, wired) \
+#define PMAP_ENTER(pmap, virtual_address, page, protection, flags, wired) \
 		MACRO_BEGIN					\
 		pmap_enter(					\
 			(pmap),					\
 			(virtual_address),			\
 			(page)->phys_addr,			\
 			(protection) & ~(page)->page_lock,	\
+			flags,					\
 			(wired)					\
 		 );						\
 		MACRO_END
 #endif	/* !PMAP_ENTER */
 
-#endif /* MACH_KERNEL_PRIVATE */
-
-/*
- * JMM - This portion is exported to other kernel components right now,
- * but will be pulled back in the future when the needed functionality
- * is provided in a cleaner manner.
- */
-
-#define PMAP_NULL  ((pmap_t) 0)
-
-extern pmap_t	kernel_pmap;			/* The kernel's map */
-#define		pmap_kernel()	(kernel_pmap)
-
 /*
  *	Routines to manage reference/modify bits based on
  *	physical addresses, simulating them if not provided
@@ -335,11 +344,6 @@ extern boolean_t	pmap_is_modified(vm_offset_t paddr);
 /*
  *	Routines that operate on ranges of virtual addresses.
  */
-extern void		pmap_remove(	/* Remove mappings. */
-				pmap_t		map,
-				vm_offset_t	s,
-				vm_offset_t	e);
-
 extern void		pmap_protect(	/* Change protections. */
 				pmap_t		map,
 				vm_offset_t	s,
@@ -352,6 +356,29 @@ extern void		(pmap_pageable)(
 				vm_offset_t	end,
 				boolean_t	pageable);
 
+#endif /* MACH_KERNEL_PRIVATE */
+
+/*
+ * JMM - This portion is exported to other kernel components right now,
+ * but will be pulled back in the future when the needed functionality
+ * is provided in a cleaner manner.
+ */
+
+#define PMAP_NULL  ((pmap_t) 0)
+
+extern pmap_t	kernel_pmap;			/* The kernel's map */
+#define		pmap_kernel()	(kernel_pmap)
+
+/* machine independent WIMG bits */
+
+#define VM_MEM_GUARDED 		0x1
+#define VM_MEM_COHERENT		0x2
+#define VM_MEM_NOT_CACHEABLE	0x4
+#define VM_MEM_WRITE_THROUGH	0x8
+
+#define VM_WIMG_MASK		0xFF
+#define VM_WIMG_USE_DEFAULT	0x80000000
+
 extern void		pmap_modify_pages(	/* Set modify bit for pages */
 				pmap_t		map,
 				vm_offset_t	s,
@@ -364,4 +391,12 @@ extern void		pmap_change_wiring(	/* Specify pageability */
 				pmap_t		pmap,
 				vm_offset_t	va,
 				boolean_t	wired);
+
+extern void		pmap_remove(	/* Remove mappings. */
+				pmap_t		map,
+				vm_offset_t	s,
+				vm_offset_t	e);
+
+#endif  /* __APPLE_API_PRIVATE */
+
 #endif	/* _VM_PMAP_H_ */
