@@ -1,21 +1,24 @@
 /*
- * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -73,13 +76,15 @@
 #include <mach/vm_behavior.h>
 #include <vm/pmap.h>
 
-typedef struct vm_map_entry	*vm_map_entry_t;
+#include <sys/appleapiopts.h>
 
-extern void	kernel_vm_map_reference(vm_map_t	map);
+#ifdef __APPLE_API_PRIVATE
 
 #ifndef MACH_KERNEL_PRIVATE
 
-struct vm_map_entry {};
+#ifdef __APPLE_API_OBSOLETE
+extern void     kernel_vm_map_reference(vm_map_t map);
+#endif /* __APPLE_API_OBSOLETE */
 
 extern void	vm_map_reference(vm_map_t	map);
 extern vm_map_t current_map(void);
@@ -96,10 +101,6 @@ extern vm_map_t current_map(void);
 #include <kern/zalloc.h>
 #include <kern/macro_help.h>
 
-#define shared_region_mapping_lock_init(object)   \
-			mutex_init(&(object)->Lock, ETAP_VM_OBJ)
-#define shared_region_mapping_lock(object)        mutex_lock(&(object)->Lock)
-#define shared_region_mapping_unlock(object)      mutex_unlock(&(object)->Lock)
 #include <kern/thread_act.h>
 
 #define current_map_fast()	(current_act_fast()->map)
@@ -114,6 +115,8 @@ extern vm_map_t current_map(void);
  *	vm_map_copy_t		represents memory copied from an address map,
  *				 used for inter-map copy operations
  */
+typedef struct vm_map_entry	*vm_map_entry_t;
+
 
 /*
  *	Type:		vm_map_object_t [internal use only]
@@ -154,7 +157,7 @@ struct vm_named_entry {
 	vm_object_t		object;		/* object I point to */
 	vm_object_offset_t	offset;		/* offset into object */
 	union {
-		ipc_port_t		pager;	/* amo pager port */
+		memory_object_t		pager;	/* amo pager port */
 		vm_map_t		map;	/* map backing submap */
 	} backing;
 	unsigned int		size;		/* size of region */
@@ -165,9 +168,6 @@ struct vm_named_entry {
 	/* boolean_t */		is_sub_map:1;	/* is object is a submap? */
 };
 
-typedef struct vm_named_entry	*vm_named_entry_t;
-
-
 /*
  *	Type:		vm_map_entry_t [internal use only]
  *
@@ -269,6 +269,7 @@ struct vm_map {
 						   for space? */
 	boolean_t		wiring_required;/* All memory wired? */
 	boolean_t		no_zero_fill;	/* No zero fill absent pages */
+	boolean_t		mapped;		/* has this map been mapped */
 	unsigned int		timestamp;	/* Version number */
 } ;
 
@@ -375,8 +376,7 @@ struct vm_map_copy {
 	int			type;
 #define VM_MAP_COPY_ENTRY_LIST		1
 #define VM_MAP_COPY_OBJECT		2
-#define VM_MAP_COPY_PAGE_LIST		3
-#define VM_MAP_COPY_KERNEL_BUFFER	4
+#define VM_MAP_COPY_KERNEL_BUFFER	3
 	vm_object_offset_t	offset;
 	vm_size_t		size;
 	union {
@@ -390,13 +390,6 @@ struct vm_map_copy {
 						 * vm_map_object_to_page_list
 						 */
 	    } c_o;
-	    struct {				/* PAGE_LIST */
-		int			npages;
-		boolean_t		page_loose;
-		vm_map_copy_cont_t	cont;
-		vm_map_copyin_args_t	cont_args;
-		vm_page_t		page_list[VM_MAP_COPY_PAGE_LIST_MAX];
-	    } c_p;
 	    struct {				/* KERNEL_BUFFER */
 		vm_offset_t		kdata;
 		vm_size_t		kalloc_size;  /* size of this copy_t */
@@ -410,12 +403,6 @@ struct vm_map_copy {
 #define cpy_object		c_u.c_o.object
 #define	cpy_index		c_u.c_o.index
 
-#define cpy_page_list		c_u.c_p.page_list
-#define cpy_npages		c_u.c_p.npages
-#define cpy_page_loose		c_u.c_p.page_loose
-#define cpy_cont		c_u.c_p.cont
-#define cpy_cont_args		c_u.c_p.cont_args
-
 #define cpy_kdata		c_u.c_k.kdata
 #define cpy_kalloc_size		c_u.c_k.kalloc_size
 
@@ -431,47 +418,6 @@ struct vm_map_copy {
 #define vm_map_copy_last_entry(copy)		\
 		((copy)->cpy_hdr.links.prev)
 
-/*
- *	Continuation macros for page list copy objects
- */
-
-#define	vm_map_copy_invoke_cont(old_copy, new_copy, result)		\
-MACRO_BEGIN								\
-	assert(vm_map_copy_cont_is_valid(old_copy));			\
-	vm_map_copy_page_discard(old_copy);				\
-	*result = (*((old_copy)->cpy_cont))((old_copy)->cpy_cont_args,	\
-					    new_copy);			\
-	(old_copy)->cpy_cont = VM_MAP_COPY_CONT_NULL;			\
-MACRO_END
-
-#define	vm_map_copy_invoke_extend_cont(old_copy, new_copy, result)	\
-MACRO_BEGIN								\
-	assert(vm_map_copy_cont_is_valid(old_copy));			\
-	*result = (*((old_copy)->cpy_cont))((old_copy)->cpy_cont_args,	\
-					    new_copy);			\
-	(old_copy)->cpy_cont = VM_MAP_COPY_CONT_NULL;			\
-MACRO_END
-
-#define vm_map_copy_abort_cont(old_copy)				\
-MACRO_BEGIN								\
-	assert(vm_map_copy_cont_is_valid(old_copy));			\
-	vm_map_copy_page_discard(old_copy);				\
-	(*((old_copy)->cpy_cont))((old_copy)->cpy_cont_args,		\
-				  (vm_map_copy_t *) 0);			\
-	(old_copy)->cpy_cont = VM_MAP_COPY_CONT_NULL;			\
-  	(old_copy)->cpy_cont_args = VM_MAP_COPYIN_ARGS_NULL;		\
-MACRO_END
-
-#define vm_map_copy_has_cont(copy)					\
-    (((copy)->cpy_cont) != VM_MAP_COPY_CONT_NULL)
-
-/*
- *	Macro to determine number of pages in a page-list copy chain.
- */
-
-#define vm_map_copy_page_count(copy)					\
-    (round_page(((vm_offset_t)(copy)->offset - trunc_page((vm_offset_t)(copy)->offset)) + (copy)->size) / PAGE_SIZE)
-
 /*
  *	Macros:		vm_map_lock, etc. [internal use only]
  *	Description:
@@ -481,23 +427,17 @@ MACRO_END
  */
 
 #define vm_map_lock_init(map)						\
-MACRO_BEGIN								\
-	lock_init(&(map)->lock, TRUE, ETAP_VM_MAP, ETAP_VM_MAP_I);	\
-	(map)->timestamp = 0;						\
-MACRO_END
-#define vm_map_lock(map)			\
-MACRO_BEGIN					\
-	lock_write(&(map)->lock);		\
-	(map)->timestamp++;			\
-MACRO_END
+	((map)->timestamp = 0 ,						\
+	lock_init(&(map)->lock, TRUE, ETAP_VM_MAP, ETAP_VM_MAP_I))
 
-#define vm_map_unlock(map)	lock_write_done(&(map)->lock)
-#define vm_map_lock_read(map)	lock_read(&(map)->lock)
-#define vm_map_unlock_read(map)	lock_read_done(&(map)->lock)
+#define vm_map_lock(map)		lock_write(&(map)->lock)
+#define vm_map_unlock(map)						\
+		((map)->timestamp++ ,	lock_write_done(&(map)->lock))
+#define vm_map_lock_read(map)		lock_read(&(map)->lock)
+#define vm_map_unlock_read(map)		lock_read_done(&(map)->lock)
 #define vm_map_lock_write_to_read(map)					\
-		lock_write_to_read(&(map)->lock)
-#define vm_map_lock_read_to_write(map)					\
-		(lock_read_to_write(&(map)->lock) || (((map)->timestamp++), 0))
+		((map)->timestamp++ ,	lock_write_to_read(&(map)->lock))
+#define vm_map_lock_read_to_write(map)	lock_read_to_write(&(map)->lock)
 
 extern zone_t		vm_map_copy_zone; /* zone for vm_map_copy structures */
 
@@ -523,12 +463,6 @@ extern boolean_t	vm_map_lookup_entry(
 				vm_offset_t	address,
 				vm_map_entry_t	*entry);	/* OUT */
 
-/* A version of vm_map_copy_discard that can be called
- * as a continuation from a vm_map_copy page list. */
-extern kern_return_t	vm_map_copy_discard_cont(
-				vm_map_copyin_args_t	cont_args,
-				vm_map_copy_t		*copy_result);/* OUT */
-
 /* Find the VM object, offset, and protection for a given virtual address
  * in the specified map, assuming a page fault of the	type specified. */
 extern kern_return_t	vm_map_lookup_locked(
@@ -731,16 +665,14 @@ extern vm_object_t	vm_submap_object;
  *	Wait and wakeup macros for in_transition map entries.
  */
 #define vm_map_entry_wait(map, interruptible)    	\
-        MACRO_BEGIN                                     \
-        assert_wait((event_t)&(map)->hdr, interruptible);	\
-        vm_map_unlock(map);                             \
-	thread_block((void (*)(void))0);		\
-        MACRO_END
+	((map)->timestamp++ ,				\
+	 thread_sleep_lock_write((event_t)&(map)->hdr,  \
+			 &(map)->lock, interruptible))
+
 
 #define vm_map_entry_wakeup(map)        thread_wakeup((event_t)(&(map)->hdr))
 
 
-
 #define	vm_map_ref_fast(map)				\
 	MACRO_BEGIN					\
 	mutex_lock(&map->s_lock);			\
@@ -787,16 +719,6 @@ extern kern_return_t	vm_map_copy_overwrite(
 				vm_map_copy_t	copy,
 				int		interruptible);
 
-/* Version of vm_map_copyout() for page list vm map copies. */
-extern kern_return_t	vm_map_copyout_page_list(
-				vm_map_t	dst_map,
-				vm_offset_t	*dst_addr,	/* OUT */
-				vm_map_copy_t	copy);
-
-/* Get rid of the pages in a page_list copy. */
-extern void		vm_map_copy_page_discard(
-				vm_map_copy_t	copy);
-
 /* Create a copy object from an object. */
 extern kern_return_t	vm_map_copyin_object(
 				vm_object_t		object,
@@ -804,17 +726,6 @@ extern kern_return_t	vm_map_copyin_object(
 				vm_object_size_t	size,
 				vm_map_copy_t		*copy_result); /* OUT */
 
-
-/* Make a copy of a region */
-/* Make a copy of a region using a page list copy */
-extern kern_return_t	vm_map_copyin_page_list(
-				vm_map_t	src_map,
-				vm_offset_t	src_addr,
-				vm_size_t	len,
-				int		options,
-				vm_map_copy_t	*copy_result,	/* OUT */
-				boolean_t	is_cont);
-
 extern vm_map_t		vm_map_switch(
 				vm_map_t	map);
 
@@ -822,22 +733,7 @@ extern int		vm_map_copy_cont_is_valid(
 				vm_map_copy_t	copy);
 
 
-
-#endif /* !MACH_KERNEL_PRIVATE */
-
-/* Get rid of a map */
-extern void		vm_map_destroy(
-				vm_map_t	map);
-/* Lose a reference */
-extern void		vm_map_deallocate(
-				vm_map_t	map);
-
-/* Create an empty map */
-extern vm_map_t		vm_map_create(
-				pmap_t		pmap,
-				vm_offset_t	min,
-				vm_offset_t	max,
-				boolean_t	pageable);
+#define VM_MAP_ENTRY_NULL	((vm_map_entry_t) 0)
 
 
 /* Enter a mapping */
@@ -870,6 +766,52 @@ extern	kern_return_t	vm_map_read_user(
 extern vm_map_t		vm_map_fork(
 				vm_map_t	old_map);
 
+/* Change inheritance */
+extern kern_return_t	vm_map_inherit(
+				vm_map_t	map,
+				vm_offset_t	start,
+				vm_offset_t	end,
+				vm_inherit_t	new_inheritance);
+
+/* Add or remove machine-dependent attributes from map regions */
+extern kern_return_t	vm_map_machine_attribute(
+				vm_map_t	map,
+				vm_offset_t	address,
+				vm_size_t	size,
+				vm_machine_attribute_t	attribute,
+				vm_machine_attribute_val_t* value); /* IN/OUT */
+/* Set paging behavior */
+extern kern_return_t	vm_map_behavior_set(
+				vm_map_t	map,
+				vm_offset_t	start,
+				vm_offset_t	end,
+				vm_behavior_t	new_behavior);
+
+extern kern_return_t	vm_map_submap(
+				vm_map_t	map,
+				vm_offset_t	start,
+				vm_offset_t	end,
+				vm_map_t	submap,
+				vm_offset_t	offset,
+				boolean_t	use_pmap);
+
+
+#endif /* MACH_KERNEL_PRIVATE */
+
+/* Create an empty map */
+extern vm_map_t		vm_map_create(
+				pmap_t		pmap,
+				vm_offset_t	min,
+				vm_offset_t	max,
+				boolean_t	pageable);
+
+/* Get rid of a map */
+extern void		vm_map_destroy(
+				vm_map_t	map);
+/* Lose a reference */
+extern void		vm_map_deallocate(
+				vm_map_t	map);
+
 /* Change protection */
 extern kern_return_t	vm_map_protect(
 				vm_map_t	map,
@@ -878,13 +820,6 @@ extern kern_return_t	vm_map_protect(
 				vm_prot_t	new_prot,
 				boolean_t	set_max);
 
-/* Change inheritance */
-extern kern_return_t	vm_map_inherit(
-				vm_map_t	map,
-				vm_offset_t	start,
-				vm_offset_t	end,
-				vm_inherit_t	new_inheritance);
-
 /* wire down a region */
 extern kern_return_t	vm_map_wire(
 				vm_map_t	map,
@@ -913,21 +848,6 @@ extern kern_return_t	vm_map_copyout(
 				vm_offset_t	*dst_addr,	/* OUT */
 				vm_map_copy_t	copy);
 
-
-/* Add or remove machine-dependent attributes from map regions */
-extern kern_return_t	vm_map_machine_attribute(
-				vm_map_t	map,
-				vm_offset_t	address,
-				vm_size_t	size,
-				vm_machine_attribute_t	attribute,
-				vm_machine_attribute_val_t* value); /* IN/OUT */
-/* Set paging behavior */
-extern kern_return_t	vm_map_behavior_set(
-				vm_map_t	map,
-				vm_offset_t	start,
-				vm_offset_t	end,
-				vm_behavior_t	new_behavior);
-
 extern kern_return_t	vm_map_copyin_common(
 				vm_map_t	src_map,
 				vm_offset_t	src_addr,
@@ -937,13 +857,16 @@ extern kern_return_t	vm_map_copyin_common(
 				vm_map_copy_t	*copy_result,	/* OUT */
 				boolean_t	use_maxprot);
 
-extern kern_return_t	vm_map_submap(
-				vm_map_t	map,
-				vm_offset_t	start,
-				vm_offset_t	end,
-				vm_map_t	submap,
-				vm_offset_t	offset,
-				boolean_t	use_pmap);
+extern kern_return_t vm_region_clone(
+				ipc_port_t	src_region,
+				ipc_port_t	dst_region);
+
+extern kern_return_t vm_map_region_replace(
+				vm_map_t	target_map,
+				ipc_port_t	old_region,
+				ipc_port_t	new_region,
+				vm_offset_t	start,  
+				vm_offset_t	end);
 
 /*
  *	Macros to invoke vm_map_copyin_common.  vm_map_copyin is the
@@ -963,8 +886,6 @@ extern kern_return_t	vm_map_submap(
 		vm_map_copyin_common(src_map, src_addr, len, src_destroy, \
 					FALSE, copy_result, TRUE)
 
-#define VM_MAP_ENTRY_NULL	((vm_map_entry_t) 0)
-
 /*
  * Flags for vm_map_remove() and vm_map_delete()
  */
@@ -973,41 +894,7 @@ extern kern_return_t	vm_map_submap(
 #define	VM_MAP_REMOVE_INTERRUPTIBLE  	0x2
 #define	VM_MAP_REMOVE_WAIT_FOR_KWIRE  	0x4
 
+#endif  /* __APPLE_API_PRIVATE */
  
-#ifdef MACH_KERNEL_PRIVATE 
-
-/* address space shared region descriptor */
-
-struct shared_region_mapping {
-        decl_mutex_data(,       Lock)   /* Synchronization */
-	int			ref_count;
-	ipc_port_t		text_region;
-	vm_size_t		text_size;
-	ipc_port_t		data_region;
-	vm_size_t		data_size;
-	vm_offset_t		region_mappings;
-	vm_offset_t		client_base;
-	vm_offset_t		alternate_base;
-	vm_offset_t		alternate_next;
-	int			flags;
-	int			depth;
-	struct shared_region_object_chain *object_chain;
-	struct shared_region_mapping *self;
-	struct shared_region_mapping *next;
-};
-
-typedef struct shared_region_mapping *shared_region_mapping_t;
-
-struct shared_region_object_chain {
-	shared_region_mapping_t	object_chain_region;
-	int			depth;
-	struct shared_region_object_chain *next;
-};
-
-typedef struct shared_region_object_chain *shared_region_object_chain_t;
-
-#endif /* MACH_KERNEL_PRIVATE */
-
-
 #endif	/* _VM_VM_MAP_H_ */
 
