@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -30,10 +33,11 @@
 #include <pexpert/boot.h>
 #include <pexpert/device_tree.h>
 #include <pexpert/pe_images.h>
-#include <kern/debug.h>
+#include <kern/sched_prim.h>
 
 #include "fakePPCStructs.h"
 #include "fakePPCDeviceTree.h"
+#include "boot_images.h"
 
 /* extern references */
 extern void pe_identify_machine(void * args);
@@ -105,11 +109,9 @@ int PE_initialize_console( PE_Video * info, int op )
 
 void PE_init_iokit(void)
 {
-    long *          dt;
-    void *          desc;
-    unsigned char * data;
-    unsigned char * clut;
-
+    long * dt;
+    int    i;
+        
     typedef struct {
         char            name[32];
         unsigned long   length;
@@ -130,7 +132,6 @@ void PE_init_iokit(void)
     if ( dt )
     {
         DriversPackageProp * prop = (DriversPackageProp *) gDriversProp.address;
-        int i;
 
         /* Copy driver info in kernBootStruct to fake device tree */
 
@@ -170,14 +171,22 @@ void PE_init_iokit(void)
      */
     DTInit(dt);
 
+    /*
+     * Fetch the CLUT and the noroot image.
+     */
+    bcopy( bootClut, appleClut8, sizeof(appleClut8) );
+
+    default_noroot.width  = kFailedBootWidth;
+    default_noroot.height = kFailedBootHeight;
+    default_noroot.dx     = 0;
+    default_noroot.dy     = kFailedBootOffset;
+    default_noroot_data   = failedBootPict;
+
     /*
      * Initialize the spinning wheel (progress indicator).
      */
-    clut = appleClut8;
-    desc = &default_progress;
-    data = default_progress_data;
-
-    vc_progress_initialize( desc, data, clut );
+    vc_progress_initialize( &default_progress, default_progress_data,
+                            (unsigned char *) appleClut8 );
 
     PE_initialize_console( (PE_Video *) 0, kPEAcquireScreen );
 
@@ -188,9 +197,6 @@ void PE_init_platform(boolean_t vm_initialized, void * args)
 {
 	if (PE_state.initialized == FALSE)
 	{
-        extern unsigned int halt_in_debugger, disableDebugOuput;
-        unsigned int        debug_arg;
-
         PE_kbp = (KERNBOOTSTRUCT *) args;
 
 	    PE_state.initialized        = TRUE;
@@ -212,19 +218,6 @@ void PE_init_platform(boolean_t vm_initialized, void * args)
              */
             PE_state.video.v_display = 0;
         }
-
-        /*
-         * If DB_HALT flag is set, then cause a breakpoint to the debugger
-         * immediately after the kernel debugger has been initialized.
-         *
-         * If DB_PRT flag is set, then enable debugger printf.
-         */
-        disableDebugOuput = TRUE; /* FIXME: override osfmk/i386/AT386/model_dep.c */
-
-        if (PE_parse_boot_arg("debug", &debug_arg)) {
-            if (debug_arg & DB_HALT) halt_in_debugger = 1;
-            if (debug_arg & DB_PRT)  disableDebugOuput = FALSE; 
-        }
     }
 
 	if (!vm_initialized)
@@ -283,9 +276,10 @@ int PE_current_console( PE_Video * info )
     return (0);
 }
 
-void PE_display_icon( unsigned int flags,
-                      const char * name )
+void PE_display_icon( unsigned int flags, const char * name )
 {
+    if ( default_noroot_data )
+        vc_display_icon( &default_noroot, default_noroot_data );
 }
 
 extern boolean_t PE_get_hotkey( unsigned char key )
